@@ -7,9 +7,13 @@
 #this should allow for somewhat cleaner code for the other functions
 #modified March 15, 2015 to add the ability to control the size of the correlation separately from the cex variable in the points
 #also added the ability to set the number of breaks in the histograms
-
+#added the hist.border parameter as suggested by Jordan Adamson  (2/11/24)
+#added ci.col and line.col parameters following  suggestions by Jordan Adamson (1/10/24)
 "pairs.panels" <-
-function (x, smooth = TRUE, scale = FALSE, density=TRUE,ellipses=TRUE,digits = 2, method="pearson",pch = 20,lm=FALSE,cor=TRUE,jiggle=FALSE,factor=2,hist.col="cyan",show.points=TRUE,rug=TRUE, breaks="Sturges", cex.cor = 1 ,wt=NULL,smoother=FALSE,stars=FALSE,ci=FALSE,alpha=.05,...)   #combines a splom, histograms, and correlations
+function (x, smooth = TRUE, scale = FALSE, density=TRUE,ellipses=TRUE,digits = 2, method="pearson",pch = 20,
+    lm=FALSE,cor=TRUE,jiggle=FALSE,factor=2,hist.col="cyan",show.points=TRUE,rug=TRUE, breaks="Sturges", 
+    cex.cor = 1 ,wt=NULL,smoother=FALSE,stars=FALSE,ci=FALSE,alpha=.05,
+    hist.border="black", line.col="blue",ci.col="light blue",...)   #combines a splom, histograms, and correlations
 {
 
 #First define all the "little functions" that are internal to pairs.panels.  This allows easier coding later
@@ -17,23 +21,23 @@ function (x, smooth = TRUE, scale = FALSE, density=TRUE,ellipses=TRUE,digits = 2
 
 "panel.hist.density" <-    
 function(x,...) {
- usr <- par("usr"); on.exit(par(usr))
+ usr <- par("usr"); on.exit(par("usr"))
   # par(usr = c(usr[1]-abs(.05*usr[1]) ,usr[2]+ abs(.05*usr[2])  , 0, 1.5) )  
      par(usr = c(usr[1] ,usr[2]  , 0, 1.5) )  
    tax <- table(x)
    if(length(tax) < 11) {breaks <- as.numeric(names(tax))
     y <- tax/max(tax)
     interbreak <- min(diff(breaks))*(length(tax)-1)/41
-    rect(breaks-interbreak,0,breaks + interbreak,y,col=hist.col)
+    rect(breaks-interbreak,0,breaks + interbreak,y,col=hist.col,border=hist.border)
     } else {
    
     h <- hist(x,breaks=breaks, plot = FALSE)
     breaks <- h$breaks; nB <- length(breaks)
   y <- h$counts; y <- y/max(y)
-    rect(breaks[-nB], 0, breaks[-1], y,col=hist.col)
+    rect(breaks[-nB], 0, breaks[-1], y,col=hist.col,border=hist.border)
     }
  if(density) { tryd <- try( d <- density(x,na.rm=TRUE,bw="nrd",adjust=1.2),silent=TRUE)
-  if(class(tryd) != "try-error") {
+  if(!inherits(tryd,"try-error")) {
      d$y <- d$y/max(d$y)
    lines(d)}}
   if(rug) rug(x)
@@ -43,7 +47,7 @@ function(x,...) {
 "panel.cor" <-
 function(x, y, prefix="",...)  {
      
-         usr <- par("usr"); on.exit(par(usr))
+         usr <- par("usr"); on.exit(par("usr"))
          par(usr = c(0, 1, 0, 1))
         if(is.null(wt)) { r  <- cor(x, y,use="pairwise",method=method)} else {
         r <- cor.wt(data.frame(x,y),w=wt[,c(1:2)])$r[1,2]}
@@ -62,7 +66,7 @@ function(x, y, prefix="",...)  {
         
 "panel.smoother" <- 
 function (x, y,pch = par("pch"), 
-    col.smooth = "red", span = 2/3, iter = 3, ...) 
+    col.smooth = line.col, span = 2/3, iter = 3,ci.cor="light grey", ...) 
 {
   # usr <- par("usr"); on.exit(par(usr))
  #  par(usr = c(usr[1]-abs(.05*usr[1]) ,usr[2]+ abs(.05*usr[2])  , usr[3],usr[4]) )     #doensn't affect the axis correctly
@@ -83,7 +87,7 @@ function (x, y,pch = par("pch"),
 
  if(ci) {  upperci <- pred$fit + confid*pred$se.fit
        lowerci <- pred$fit - confid*pred$se.fit 
-      polygon(c(tempx$x,rev(tempx$x)),c(lowerci,rev(upperci)),col=adjustcolor("light grey", alpha.f=0.8), border=NA)
+      polygon(c(tempx$x,rev(tempx$x)),c(lowerci,rev(upperci)),col=adjustcolor(ci.col, alpha.f=0.8), border=NA)
         }
      lines(tempx$x,pred$fit,  col = col.smooth, ...)   #this is the loess fit
 }  else {if(smooth)  lines(stats::lowess(x[ok],y[ok],f=span,iter=iter),col=col.smooth) }}
@@ -92,7 +96,7 @@ function (x, y,pch = par("pch"),
 
  "panel.lm" <- 
 function (x, y,  pch = par("pch"), 
-    col.lm = "red",  ...) 
+    col.lm = "red", ci.col="blue", ...) 
 {   ymin <- min(y)
     ymax <- max(y)
     xmin <- min(x)
@@ -112,7 +116,7 @@ function (x, y,  pch = par("pch"),
    		 pred <-  predict.lm(lml,newdata=tempx,se.fit=TRUE)  #from Julian Martins 
    		 upperci <- pred$fit + confid*pred$se.fit
    		 lowerci <- pred$fit - confid*pred$se.fit
-     	 polygon(c(tempx$x,rev(tempx$x)),c(lowerci,rev(upperci)),col=adjustcolor("light grey", alpha.f=0.8), border=NA)
+     	 polygon(c(tempx$x,rev(tempx$x)),c(lowerci,rev(upperci)),col=adjustcolor(ci.col, alpha.f=0.8), border=NA)
            }
     if(ellipses) {
     	xm <- mean(x,na.rm=TRUE)
@@ -146,7 +150,7 @@ function (x, y,  pch = par("pch"),
 function (x, y,   pch = par("pch"), 
      col.smooth = "red", ...) 
  { segments=51
-  usr <- par("usr"); on.exit(par(usr))
+  usr <- par("usr"); on.exit(par("usr"))
   par(usr = c(usr[1]-abs(.05*usr[1]) ,usr[2]+ abs(.05*usr[2])  , 0, 1.5) ) 
  xm <- mean(x,na.rm=TRUE)
   ym <- mean(y,na.rm=TRUE)
