@@ -8,8 +8,9 @@
 #Further modified 9/30/23 to force 1 factor solution length(keys < 4)
 #added the covar option 10/23/23
 #added fm option  2/29/24
-reliability <- function(keys=NULL,items,nfactors=2,n.obs=NA,split=TRUE,raw=TRUE,plot=FALSE,hist=FALSE,
-   n.sample=10000,brute=FALSE,check.keys=TRUE,covar=FALSE,fm="minres", weighted="min")  {
+#fixed call to unidim to pass the nfactors argument   9/23/24
+reliability <- function(keys=NULL,items,nfactors=2,n.obs=NA,split=TRUE,raw=TRUE,plot=FALSE,plot.sum=TRUE,hist=FALSE,
+   n.sample=10000,brute=FALSE,check.keys=TRUE,covar=FALSE,fm="minres", rotate="oblimin", weighted="min")  {
    cl <- match.call()
   result <- list()
   splits <- list()
@@ -40,12 +41,12 @@ reliability <- function(keys=NULL,items,nfactors=2,n.obs=NA,split=TRUE,raw=TRUE,
   scale.key <- keys[[scales]]
  select <- selectFromKeys(scale.key)
  if(length(select)>1 )  {
-  if (length(select)< 4) {nfactors <- 1} else {nfactors <- NFACTORS}   #omegah with 2 factors is not defined for nvar<=5
-  if(cors) {om <- omegah(items[select,select], nfactors=nfactors,plot=plot,two.ok=TRUE,fm=fm)
+  if (length(select)< 4) {NFACTORS <- 1} else {NFACTORS <- NFACTORS}   #omegah with 2 factors is not defined for nvar<=5
+  if(cors) {om <- omegah(items[select,select], nfactors=NFACTORS,plot=plot,two.ok=TRUE,fm=fm,rotate=rotate)
            } else {
-   om <- omegah(items[,select], nfactors=nfactors,n.obs=n.obs,plot=plot,two.ok=TRUE,covar=covar,fm=fm)
+   om <- omegah(items[,select], nfactors=NFACTORS,n.obs=n.obs,plot=plot,two.ok=TRUE,covar=covar,fm=fm, rotate=rotate)
      }
- 	uni <- unidim(om$R, n.obs=n.obs)  #use the R object rather than redoing the factoring
+ 	uni <- unidim(om$R, n.obs=n.obs, nfactors=NFACTORS) #use the R object rather than redoing the factoring
    
 
   if(split){temp.keys <- colnames(om$R) <-  gsub("-","",colnames(om$R))
@@ -63,18 +64,21 @@ reliability <- function(keys=NULL,items,nfactors=2,n.obs=NA,split=TRUE,raw=TRUE,
                     u=uni$u[1],tau=uni$u[2],cong=uni$u[3],
                 maxrb=split.half$maxrb,minrb=split.half$minrb,
                 mean.r=split.half$av.r, med.r <- split.half$med.r, n.items=length(select),
-                 CFI <- uni$uni[7], ECV = uni$uni[8], beta=ic$beta, f1f2 =uni$uni[9])  
+                 CFI <- uni$uni[7], ECV = uni$uni[8], beta=ic$beta, f1f2 =uni$uni[9],  MAP <- uni$uni[10]
+                 )  
           if(raw) {splits[[scales]] <- split.half$raw}
            } else { 
                rownames(om$R) <- colnames(om$R) <-  gsub("-","",colnames(om$R))
                ic <- suppressWarnings(iclust(om$R,1,n.obs=n.obs, plot=FALSE,reliability=FALSE))    
    result[[scales]] <- list(omega_h = om$omega_h, alpha = om$alpha, omega.tot = om$omega.tot,
                      u=uni$u[1],tau=uni$u[2],
-                     cong=uni$u[3],n.items=length(select),
+                     cong=uni$u[3],
+                     n.items=length(select),
                      CFI <- uni$uni[7], 
                      ECV = uni$uni[8],
                      beta =ic$beta)
                      f1f2 = uni$uni[9]
+                     MAP <- uni$uni[10]
                      }
                      
                   
@@ -89,8 +93,9 @@ reliability <- function(keys=NULL,items,nfactors=2,n.obs=NA,split=TRUE,raw=TRUE,
   #if(split) {ncol <- 14} else {ncol <- 12}
   ncol <- length(result[[1]])
    result.df <- matrix(unlist(result[!is.null(result)]), ncol=ncol,byrow=TRUE)
-  if(split) {   colnames(result.df) <- c("omega_h", "alpha", "omega.tot", "Uni","tau","cong","max.split","min.split","mean.r", "med.r", "n.items","CFI","ECV","Beta", "EVR")} else {
-  colnames(result.df) <- c("omega.h", "alpha", "omega.tot","Uni","tau","cong","n.items","CFI","ECV","Beta", "EVR")}
+   #EVR is the ratio of the first to second eigen value
+  if(split) {   colnames(result.df) <- c("omega_h", "alpha", "omega.tot", "Uni","tau","cong","max.split","min.split","mean.r", "med.r", "n.items","CFI","ECV","Beta", "EVR","MAP")} else {
+  colnames(result.df) <- c("omega.h", "alpha", "omega.tot","Uni","tau","cong","n.items","CFI","ECV","Beta", "EVR","MAP")}
   rownames(result.df) <- unlist(res.name)
   if(raw) {
   lx <- unlist(lapply(splits,length))
@@ -107,9 +112,11 @@ reliability <- function(keys=NULL,items,nfactors=2,n.obs=NA,split=TRUE,raw=TRUE,
   result <- list(result.df = result.df,splits= splits,max=best,min=worst, Call = cl)
   if(hist) {multi.hist(splits)}
   class(result) <-  c("psych","reliability")
+  if(plot.sum) {plot(result)}
   return(result) } else {
 
    class(result.df) <- c("psych","reliability", "matrix")
+   if(plot.sum) {plot(result.df)}
   return(result.df)
   }
   }
